@@ -525,7 +525,7 @@ class Environment:
             if not loc.exists():
                 continue
             for pth in loc.iterdir():
-                if not pth.suffix == ".egg-link":
+                if pth.suffix != ".egg-link":
                     continue
                 contents = [
                     normalize_path(line.strip()) for line in pth.read_text().splitlines()
@@ -688,10 +688,10 @@ class Environment:
 
         tree = PackageDAG.from_pkgs(packages).sort()
         branch_keys = {r.key for r in flatten(tree.values())}
-        if pkg is not None:
-            nodes = [p for p in tree.keys() if p.key == pkg]
+        if pkg is None:
+            nodes = [p for p in tree if p.key not in branch_keys]
         else:
-            nodes = [p for p in tree.keys() if p.key not in branch_keys]
+            nodes = [p for p in tree if p.key == pkg]
         key_tree = {k.key: v for k, v in tree.items()}
 
         return [self._get_requirements_for_package(p, key_tree) for p in nodes]
@@ -769,7 +769,13 @@ class Environment:
             None,
         )
         if match is not None:
-            if req.editable and req.link and req.link.is_file:
+            if req.specifier is not None:
+                return SpecifierSet(str(req.specifier)).contains(
+                    match.version, prereleases=True
+                )
+            if req.link is None:
+                return True
+            elif req.editable and req.link.is_file:
                 requested_path = req.link.file_path
                 if os.path.exists(requested_path):
                     local_path = requested_path
@@ -794,12 +800,8 @@ class Environment:
                     and vcs_ref == requested_revision
                     and direct_url_metadata["url"] == pipfile_part[req.link.scheme]
                 )
-            elif req.link and req.link.is_vcs:
+            elif req.link.is_vcs:
                 return False
-            elif req.specifier is not None:
-                return SpecifierSet(str(req.specifier)).contains(
-                    match.version, prereleases=True
-                )
             return True
         return False
 
